from mdatasets.allscrap import scrape_data
from mdatasets.hugg_data import huggingface_dataset
from mdatasets.kag import kaggle_dataset
from mdatasets.mdweb import run_command, text_search, text_search_with_download, image_search, news_search, save_news_tocsv, answers_search
from mdatasets.moptical_display import display_totext
from mdatasets.moptical_pdf import pdf_totext
from mdatasets.multi_thread import cpu_info
from mdatasets.petals_lm import load_petals, generate_text
from mdatasets.tor_circuit import request_tor, request_multiprocessing
